@@ -1333,7 +1333,7 @@ static volatile gboolean critical = FALSE;
     avi_file,AVIファイル構造体
          pos,読み込むサンプル番号
          RET,バイト数                                                       */
-gint
+gsize
 avi_read_video_size (AviFile    *avi_file,
                      const gint  pos)
 {
@@ -1408,7 +1408,7 @@ avi_read_video (AviFile    *avi_file,
        start,取得する実サンプル番号
      samples,実サンプル数
          RET,バイト数                                                       */
-gboolean
+gsize
 avi_read_audio_size (AviFile    *avi_file,
                      const gint  start,
                      const gint  samples)
