@@ -1104,7 +1104,7 @@ bitmap_convert_16 (const BitmapInfoHeader *bmih0,
                                 | ((p[j * pixel_bytes + 1] << 2) & 0x03e0)
                                 | ((p[j * pixel_bytes + 2] << 7) & 0x7c00));
       p += length0;
-      (guint8 *)q += length1;
+      q = (guint16 *)((guint8 *)q + length1);
     }
 }
 
@@ -1240,10 +1240,10 @@ bitmap_convert_24 (const BitmapInfoHeader *bmih0,
                   bit = 0;
                   for (shift = 0x80000000; shift != 0; shift >>= 1)
                     {
-                      if (mask[k]&shift)
+                      if (mask[k] & shift)
                         {
                           q[j * 3 + k] <<= 1;
-                          if (GUINT32_FROM_LE(((guint32 *)p)[j])&shift)
+                          if (GUINT32_FROM_LE (((guint32 *)p)[j]) & shift)
                             q[j * 3 + k] |= 1;
                           if (++bit >= 8)
                             break;
