@@ -443,7 +443,7 @@ icm_unref (IcmObject *icm_object)
 }
 
 
-/*  ja:Codecをコピーする
+/*  ja:Codecを複製する
     icm_object,IcmObject
            RET,IcmObject,NULL:エラー                                        */
 IcmObject *
@@ -817,8 +817,8 @@ icm_compress_frames_info (IcmObject              *icm_object,
       ICCOMPRESSFRAMES iccompressframes;
 
       g_memset (&iccompressframes, 0, sizeof (ICCOMPRESSFRAMES));
-      (BitmapInfoHeader *)iccompressframes.lpbiOutput = icm_object->bmih_out;
-      (BitmapInfoHeader *)iccompressframes.lpbiInput = icm_object->bmih_in;
+      iccompressframes.lpbiOutput = (LPBITMAPINFOHEADER)icm_object->bmih_out;
+      iccompressframes.lpbiInput = (LPBITMAPINFOHEADER)icm_object->bmih_in;
       iccompressframes.lQuality = icm_object->quality;
       iccompressframes.lDataRate = data_rate > 0 ? data_rate : G_MAXINT;
       iccompressframes.lKeyRate = icm_object->key_frame;
@@ -913,9 +913,9 @@ icm_compress (IcmObject      *icm_object,
     return 0;
   iccompress.dwFlags = icm_object->key_point % icm_object->key_frame == 0
                                                     ? ICCOMPRESS_KEYFRAME : 0;
-  (BitmapInfoHeader *)iccompress.lpbiOutput = icm_object->bmih_out;
+  iccompress.lpbiOutput = (LPBITMAPINFOHEADER)icm_object->bmih_out;
   iccompress.lpOutput = output;
-  (BitmapInfoHeader *)iccompress.lpbiInput = icm_object->bmih_in;
+  iccompress.lpbiInput = (LPBITMAPINFOHEADER)icm_object->bmih_in;
   iccompress.lpInput = input;
   iccompress.lpckid = &dwID;
   iccompress.lpdwFlags = &dwFlags;
@@ -924,7 +924,7 @@ icm_compress (IcmObject      *icm_object,
   iccompress.dwQuality = icm_object->quality;
   if (icm_object->frame > 0)
     {
-      (BitmapInfoHeader *)iccompress.lpbiPrev = icm_object->bmih_in;
+      iccompress.lpbiPrev = (LPBITMAPINFOHEADER)icm_object->bmih_in;
       iccompress.lpPrev = icm_object->prev;
     }
   else
@@ -1132,9 +1132,9 @@ icm_decompress (IcmObject      *icm_object,
     icdecompress.dwFlags |= ICDECOMPRESS_NULLFRAME;
   if (flags & ICM_DECOMPRESS_NOTKEYFRAME)
     icdecompress.dwFlags |= ICDECOMPRESS_NOTKEYFRAME;
-  (BitmapInfoHeader *)icdecompress.lpbiInput = icm_object->bmih_in;
+  icdecompress.lpbiInput = (LPBITMAPINFOHEADER)icm_object->bmih_in;
   icdecompress.lpInput = input;
-  (BitmapInfoHeader *)icdecompress.lpbiOutput = icm_object->bmih_out;
+  icdecompress.lpbiOutput = (LPBITMAPINFOHEADER)icm_object->bmih_out;
   icdecompress.lpOutput = output;
   icdecompress.ckid = 0;
   return SendDriverMessage (icm_object->hDrvr, ICM_DECOMPRESS,
