@@ -114,7 +114,7 @@ MiscCreateMenuEntry menu_entries[] = {
 {"/view/frame",         N_("Selected _Frame"), NULL,          NULL,             MISC_CREATE_MENU_CHECK,                             command_frame,    NULL, NULL},
 {"/option",             N_("_Option"),         NULL,          NULL,             MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
 {"/option/",            NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
-{"/option/preferences", GTK_STOCK_PREFERENCES, NULL,          NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_conf,     NULL, NULL},
+{"/option/preferences", GTK_STOCK_PREFERENCES, NULL,          NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_pref,     NULL, NULL},
 {"/task",               N_("_Task"),           NULL,          NULL,             MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_DISABLE,   NULL,             NULL, NULL},
 {"/task/",              NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
 {"/task/cancel",        GTK_STOCK_CANCEL,      NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_cancel,   NULL, NULL},
@@ -176,16 +176,7 @@ main (int   argc,
       char *argv[])
 {
   gboolean *arg_files, success[4];
-  gchar *user_config = NULL;
-#if ! GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32)
-  LPITEMIDLIST pidl = NULL;
-#endif /* ! GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32) */
-#ifndef LOCALEDIR
-  gchar *dirname, *path, *locale;
-# if GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32)
-  gchar *temp;
-# endif /* GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32) */
-#endif /* not LOCALEDIR */
+  const gchar *user_config;
   gint i, count = 0, license = -1;
   GKeyFile *key_file;
   GList *glist;
@@ -229,34 +220,7 @@ main (int   argc,
   gtk_set_locale ();
   gtk_init (&argc, &argv);
   gdk_rgb_init ();
-#ifdef LOCALEDIR
-  bindtextdomain (PACKAGE, LOCALEDIR);
-#else /* not LOCALEDIR */
-  path = fileio_get_full_path (argv[0]);
-  dirname = g_path_get_dirname (path);
-  g_free (path);
-  locale = g_build_filename (dirname, "locale", NULL);
-  g_free (dirname);
-# ifdef G_OS_WIN32
-  if (!g_file_test (locale, G_FILE_TEST_EXISTS))
-    {
-      g_free (locale);
-      locale = g_win32_get_package_installation_subdirectory
-                            (NULL, argv[0], "lib" G_DIR_SEPARATOR_S "locale");
-    }
-#  if GLIB_CHECK_VERSION(2,6,0)
-#   if GLIB_CHECK_VERSION(2,8,0)
-  temp = g_win32_locale_filename_from_utf8 (locale);
-#   else /* not GLIB_CHECK_VERSION(2,8,0) */
-  temp = g_locale_from_utf8 (locale, -1, NULL, NULL, NULL);
-#   endif /* not GLIB_CHECK_VERSION(2,8,0) */
-  g_free (locale);
-  locale = temp;
-#  endif /* GLIB_CHECK_VERSION(2,6,0) */
-# endif /* G_OS_WIN32 */
-  bindtextdomain (PACKAGE, locale);
-  g_free (locale);
-#endif /* not LOCALEDIR */
+  bindtextdomain (PACKAGE, misc_spec_locale (argv[0]));
   bind_textdomain_codeset (PACKAGE, "UTF-8");
   textdomain (PACKAGE);
   avi_init ();
@@ -269,39 +233,7 @@ main (int   argc,
   history = orz_history_new ();
 
   /* ja:キーファイルを求める */
-#ifdef G_OS_WIN32
-# if GLIB_CHECK_VERSION(2,6,0)
-  user_config = g_build_filename (g_get_user_config_dir (),
-                                    "maid.org", "vmaid", "vmaid.ini", NULL);
-# else /* not GLIB_CHECK_VERSION(2,6,0) */
-  if (SHGetSpecialFolderLocation (NULL, CSIDL_APPDATA, &pidl) == S_OK)
-    {
-      TCHAR szPath[MAX_PATH + 1];
-
-      if (SHGetPathFromIDList (pidl, szPath))
-#  ifdef UNICODE
-        {
-          gchar *dir, *utf8str;
-
-          utf8str = g_utf16_to_utf8 (szPath, -1, NULL, NULL, NULL);
-          dir = g_filename_from_utf8 (utf8str, -1, NULL, NULL, NULL);
-          g_free (utf8str);
-          user_config = g_build_filename (dir,
-                                    "maid.org", "vmaid", "vmaid.ini", NULL);
-          g_free (dir);
-        }
-#  else /* not UNICODE */
-        user_config = g_build_filename (szPath,
-                                    "maid.org", "vmaid", "vmaid.ini", NULL);
-#  endif /* not UNICODE */
-      CoTaskMemFree (pidl);
-    }
-  if (!user_config)
-    user_config = g_build_filename (g_get_home_dir (), "vmaid.ini", NULL);
-# endif /* not GLIB_CHECK_VERSION(2,6,0) */
-#else /* not G_OS_WIN32 */
-  user_config = g_build_filename (g_get_home_dir (), ".vmaid", NULL);
-#endif /* not G_OS_WIN32 */
+  user_config = misc_spec_config ("maid.org", "vmaid", "main");
 
   /* ja:レジストリから読み出す */
   key_file = g_key_file_new ();
@@ -309,17 +241,15 @@ main (int   argc,
     {
       gchar *utf8str;
 
-      license = g_key_file_get_integer (key_file, "vmaid", "license", NULL);
+      license = g_key_file_get_integer (key_file, "license", "hash", NULL);
       orz_history_set_num (ORZ_HISTORY (history),
-                g_key_file_get_integer (key_file, "vmaid", "history", NULL));
+                g_key_file_get_integer (key_file, "pref", "history", NULL));
+      newfile = g_key_file_get_boolean (key_file, "pref", "newfile", NULL);
+      second = g_key_file_get_boolean (key_file, "pref", "second", NULL);
+      def_width = g_key_file_get_integer (key_file, "pref", "width", NULL);
+      def_height = g_key_file_get_integer (key_file, "pref", "height", NULL);
+      n_pos = g_key_file_get_integer (key_file, "pref", "n_pos", NULL);
       addext = g_key_file_get_boolean (key_file, "vmaid", "addext", NULL);
-      newfile = g_key_file_get_boolean (key_file, "vmaid", "newfile", NULL);
-      second = g_key_file_get_boolean (key_file, "vmaid", "second", NULL);
-      def_width = g_key_file_get_integer (key_file, "vmaid", "def_width",
-                                                                        NULL);
-      def_height = g_key_file_get_integer (key_file, "vmaid", "def_height",
-                                                                        NULL);
-      n_pos = g_key_file_get_integer (key_file, "vmaid", "n_pos", NULL);
       default_ratio = g_key_file_get_boolean (key_file, "vmaid", "ratio",
                                                                         NULL);
       file_merge = g_key_file_get_boolean (key_file, "vmaid", "merge", NULL);
@@ -340,8 +270,8 @@ main (int   argc,
         {
           gchar *key;
 
-          key = g_strdup_printf ("history%d", i);
-          utf8str = g_key_file_get_string (key_file, "vmaid", key, NULL);
+          key = g_strdup_printf ("file%d", i);
+          utf8str = g_key_file_get_string (key_file, "history", key, NULL);
           g_free (key);
           if (utf8str)
             {
@@ -364,7 +294,7 @@ main (int   argc,
   /* ja:コマンドラインの解析 */
   {
     gint array[2], def[2];
-    ArgumentBool arg_n, arg_x;
+    ArgumentBool arg_n, arg_p, arg_x;
     ArgumentValue arg_h;
     ArgumentArray arg_s;
     ArgumentExit arg_v;
@@ -372,6 +302,7 @@ main (int   argc,
     ArgumentList arg_opts[] = {
 {"history", 'h',  "NUM",          N_("History"),     ARGUMENT_TYPE_VALUE, &arg_h},
 {"new",     'n',  "ON/OFF",       N_("New File"),    ARGUMENT_TYPE_BOOL,  &arg_n},
+{"profile", 'p',  "ON/OFF",       N_("Profile"),     ARGUMENT_TYPE_BOOL,  &arg_p},
 {"size",    's',  "WIDTH,HEIGHT", N_("Window Size"), ARGUMENT_TYPE_ARRAY, &arg_s},
 {"second",  'x',  "ON/OFF",       N_("Open Window"), ARGUMENT_TYPE_BOOL,  &arg_x},
 {"version", 'v',  NULL,           N_("About"),       ARGUMENT_TYPE_EXIT,  &arg_v},
@@ -384,6 +315,9 @@ main (int   argc,
     /* ja:新規ファイル */
     arg_n.flag = newfile;
     arg_n.def = FALSE;
+    /* ja:レジストリ */
+    arg_p.flag = TRUE;
+    arg_p.def = TRUE;
     /* ja:ウインドウサイズ */
     array[0] = def_width;
     array[1] = def_height;
@@ -405,6 +339,9 @@ VMAID_COPYRIGHT_NOTICE"\n"
     arg_q.str = VMAID_COPYRIGHT_NOTICE"\n\n";
     arg_files = arg_analyse (argv, arg_opts);
     orz_history_set_num (ORZ_HISTORY (history), arg_h.val);
+    newfile = arg_n.flag;
+    if (!arg_p.flag)
+      user_config = NULL;
     def_width = array[0];
     def_height = array[1];
     second = arg_x.flag;
@@ -688,15 +625,15 @@ VMAID_COPYRIGHT_NOTICE"\n"
 
       key_file = g_key_file_new ();
       g_key_file_load_from_file (key_file, user_config, G_KEY_FILE_NONE, NULL);
-      g_key_file_set_integer (key_file, "vmaid", "license", license);
-      g_key_file_set_integer (key_file, "vmaid", "history",
+      g_key_file_set_integer (key_file, "license", "hash", license);
+      g_key_file_set_integer (key_file, "pref", "history",
                                 orz_history_get_num (ORZ_HISTORY (history)));
+      g_key_file_set_boolean (key_file, "pref", "newfile", newfile);
+      g_key_file_set_boolean (key_file, "pref", "second", second);
+      g_key_file_set_integer (key_file, "pref", "width", def_width);
+      g_key_file_set_integer (key_file, "pref", "height", def_height);
+      g_key_file_set_integer (key_file, "pref", "n_pos", n_pos);
       g_key_file_set_boolean (key_file, "vmaid", "addext", addext);
-      g_key_file_set_boolean (key_file, "vmaid", "newfile", newfile);
-      g_key_file_set_boolean (key_file, "vmaid", "second", second);
-      g_key_file_set_integer (key_file, "vmaid", "def_width", def_width);
-      g_key_file_set_integer (key_file, "vmaid", "def_height", def_height);
-      g_key_file_set_integer (key_file, "vmaid", "n_pos", n_pos);
       g_key_file_set_boolean (key_file, "vmaid", "ratio", default_ratio);
       g_key_file_set_boolean (key_file, "vmaid", "merge", file_merge);
       g_key_file_set_integer (key_file, "vmaid", "view", default_view);
@@ -730,12 +667,12 @@ VMAID_COPYRIGHT_NOTICE"\n"
         {
           gchar *key, *utf8str;
 
-          key = g_strdup_printf ("history%d", i);
+          key = g_strdup_printf ("file%d", i);
           utf8str = g_filename_to_utf8 (g_list_nth_data (glist, i), -1,
                                                             NULL, NULL, NULL);
           if (utf8str)
             {
-              g_key_file_set_string (key_file, "vmaid", key, utf8str);
+              g_key_file_set_string (key_file, "history", key, utf8str);
               g_free (utf8str);
             }
           g_free (key);
@@ -745,8 +682,8 @@ VMAID_COPYRIGHT_NOTICE"\n"
         {
           gchar *key;
 
-          key = g_strdup_printf ("history%d", i++);
-          g_key_file_remove_key (key_file, "vmaid", key, NULL);
+          key = g_strdup_printf ("file%d", i++);
+          g_key_file_remove_key (key_file, "history", key, NULL);
           g_free (key);
         }
       data = g_key_file_to_data (key_file, &length, NULL);
@@ -759,7 +696,6 @@ VMAID_COPYRIGHT_NOTICE"\n"
     }
 
   gdk_font_unref (system_font);
-  g_free (user_config);
   g_free (open_path);
   g_free (save_path);
   gtk_exit (0);
